import pytest

from webpageinfo.page import extract_tags_from_words


@pytest.mark.parametrize(
    "words, expected",
    [
        (["vincent"] * 6, ["vincent"]),
        (["123456"] * 6, []),
        (["ou", "et", "or", "ni"] * 6, []),
        (["Title"] * 6, []),
        (["005056A90321"] * 6, []),
        (["6C1Cdb98"] * 6, []),
        (["serait"] * 6, []),
        (["90Cdbf"] * 6, []),
        (["Rc2Bc2A9Bg67"] * 6, []),
    ],
)
def test_extract_tags_from_words(words, expected):
    assert extract_tags_from_words(words) == expected



ignored_html_tags = {
    "article",
    "aside",
    "blockquote",
    "body",
    "cite",
    "dialog",
    "figcaption",
    "figure",
    "footer",
    "frameset",
    "frame",  # TODO choper le contenu
    "header",
    "iframe",  # TODO choper le contenu
    "label",
    "main",
    "noframe",
    "noframes",
    "section",
    "show",
    "tbody",
    "transition",  # vue.js
    "time",
    "tt",
}



svg_tags = {
    "a",
    "animate",
    "animatemotion",
    "animatetransform",
    "area",
    "circle",
    "clippath",
    "defs",
    "desc",
    "ellipse",
    "feblend",
    "fecolormatrix",
    "fecomponenttransfer",
    "fecomposite",
    "feconvolvematrix",
    "fediffuselighting",
    "fedisplacementmap",
    "fedistantlight",
    "fedropshadow",
    "feflood",
    "fefunca",
    "fefuncb",
    "fefuncg",
    "fefuncr",
    "fegaussianblur",
    "feimage",
    "femerge",
    "femergenode",
    "femorphology",
    "feoffset",
    "fepointlight",
    "fespecularlighting",
    "fespotlight",
    "fetile",
    "feturbulence",
    "filter",
    "foreignobject",
    "g",
    "hatch",
    "hatchpath",
    "image",
    "line",
    "lineargradient",
    "map",
    "marker",
    "mask",
    "metadata",
    "mpath",
    "path",
    "pattern",
    "polygon",
    "polyline",
    "radialgradient",
    "rect",
    "script",
    "set",
    "stop",
    "style",
    "svg",
    "switch",
    "symbol",
    "text",
    "textpath",
    "title",
    "tspan",
    "use",
    "view",
}



removed_html_tags = {
    "apcomments",
    "audio",
    "button",
    "canvas",
    "form",
    "g:plusone",
    "g-popup",
    "hr",
    "input",
    "link",
    "meta",
    "nav",
    "noscript",
    "object",
    "script",
    "select",
    "source",
    "style",
    "svg",
    "video-js",
}
